EvoDAG
=========================================


.. image:: https://github.com/mgraffg/EvoDAG/actions/workflows/test.yaml/badge.svg
		:target: https://github.com/mgraffg/EvoDAG/actions/workflows/test.yaml

.. image:: https://coveralls.io/repos/github/mgraffg/EvoDAG/badge.svg?branch=develop
		:target: https://coveralls.io/github/mgraffg/EvoDAG?branch=develop

.. image:: https://badge.fury.io/py/evodag.svg
		:target: https://badge.fury.io/py/evodag

.. image:: https://dev.azure.com/conda-forge/feedstock-builds/_apis/build/status/evodag-feedstock?branchName=main
		:target: https://dev.azure.com/conda-forge/feedstock-builds/_build/latest?definitionId=16226&branchName=main

.. image:: https://img.shields.io/conda/vn/conda-forge/evodag.svg
		:target: https://anaconda.org/conda-forge/evodag

.. image:: https://img.shields.io/conda/pn/conda-forge/evodag.svg
		:target:  https://anaconda.org/conda-forge/evodag		


Evolving Directed Acyclic Graph (EvoDAG) is a steady-state Genetic
Programming system with tournament selection.

More information can be found on `EvoDAG <http://github.com/mgraffg/EvoDAG>`_.
